@@ -7,7 +7,7 @@ use SDL::Event;
 use SDL::Events;
 
 use SDLx::Controller::Interface;
-my $app = SDLx::App->new( w => 200, h => 200, title => "timestep", delay => 10 );
+my $app = SDLx::App->new( w => 200, h => 200, title => "timestep" );
 
 #The initial x and y for this object.
 my $spring = SDLx::Controller::Interface->new( x => 100, y => 100 );
@@ -24,6 +24,7 @@ my $accel = sub {
 	my $k  = 10;
 	my $b  = 1;
 	my $ax = ( ( -1 * $k ) * ( $state->x ) - $b * $state->v_x );
+
 	return ( $ax, 0, 0 );
 };
 $spring->set_acceleration($accel);
@@ -34,15 +35,23 @@ my $render = sub {
 	$app->draw_rect( [ 100 - $state->x, $state->y, 2, 2 ], 0xFF0FFF );
 };
 
+#an event handler to exit
+my $event = sub {
+	return 0 if $_[0]->type == SDL_QUIT;
+	return 1;
+};
+
+
+$app->add_event_handler($event);
+
 #clear the screen
 $app->add_show_handler( sub { $app->draw_rect( [ 0, 0, $app->w, $app->h ], 0x000000 ) } );
 
 #add the spring
-$spring->attach( $app, $render );
+$spring->attach($app, $render );
 
 #add the constant_velocity
-$constant->attach(
-	$app,
+$constant->attach( $app,
 	sub {
 		my $state = shift;
 		$app->draw_rect( [ $state->x, $state->y, 4, 4 ], 0xFFFFFF );
